pub struct Deriver<'a> { /* private fields */ }Expand description
Ethereum address deriver.
Implementations
Sourceimpl<'a> Deriver<'a>
impl<'a> Deriver<'a>
Sourcepub fn derive_with(
&self,
style: DerivationStyle,
index: u32,
) -> Result<DerivedAccount, DeriveError>
pub fn derive_with( &self, style: DerivationStyle, index: u32, ) -> Result<DerivedAccount, DeriveError>
Sourcepub fn derive_many_with(
&self,
style: DerivationStyle,
start: u32,
count: u32,
) -> Result<Vec<DerivedAccount>, DeriveError>
pub fn derive_many_with( &self, style: DerivationStyle, start: u32, count: u32, ) -> Result<Vec<DerivedAccount>, DeriveError>
Derive count accounts starting at start with a specific style.
Errors
Returns an error if any individual derivation fails or start + count overflows.
Sourcepub fn derive_at(&self, path: &str) -> Result<DerivedAccount, DeriveError>
pub fn derive_at(&self, path: &str) -> Result<DerivedAccount, DeriveError>